@@ -1,18 +1,11 @@
+import contextlib
+
 import pytest
+asyncio = pytest.importorskip("asyncio")
 aiohttp = pytest.importorskip("aiohttp")
 
-import asyncio  # noqa: E402
-import contextlib  # noqa: E402
-
-import pytest  # noqa: E402
 import vcr  # noqa: E402
-
-from .aiohttp_utils import aiohttp_request  # noqa: E402
-
-try:
-    from .async_def import test_http  # noqa: F401
-except SyntaxError:
-    pass
+from .aiohttp_utils import aiohttp_app, aiohttp_request  # noqa: E402
 
 
 def run_in_loop(fn):
@@ -22,19 +15,19 @@ def run_in_loop(fn):
         return loop.run_until_complete(task)
 
 
-def request(method, url, as_text=True, **kwargs):
+def request(method, url, output='text', **kwargs):
     def run(loop):
-        return aiohttp_request(loop, method, url, as_text, **kwargs)
+        return aiohttp_request(loop, method, url, output=output, **kwargs)
 
     return run_in_loop(run)
 
 
-def get(url, as_text=True, **kwargs):
-    return request('GET', url, as_text, **kwargs)
+def get(url, output='text', **kwargs):
+    return request('GET', url, output=output, **kwargs)
 
 
-def post(url, as_text=True, **kwargs):
-    return request('POST', url, as_text, **kwargs)
+def post(url, output='text', **kwargs):
+    return request('POST', url, output='text', **kwargs)
 
 
 @pytest.fixture(params=["https", "http"])
@@ -78,15 +71,28 @@ def test_text(tmpdir, scheme):
 
 def test_json(tmpdir, scheme):
     url = scheme + '://httpbin.org/get'
+    headers = {'Content-Type': 'application/json'}
+
     with vcr.use_cassette(str(tmpdir.join('json.yaml'))):
-        _, response_json = get(url, as_text=False)
+        _, response_json = get(url, output='json', headers=headers)
 
     with vcr.use_cassette(str(tmpdir.join('json.yaml'))) as cassette:
-        _, cassette_response_json = get(url, as_text=False)
+        _, cassette_response_json = get(url, output='json', headers=headers)
         assert cassette_response_json == response_json
         assert cassette.play_count == 1
 
 
+def test_binary(tmpdir, scheme):
+    url = scheme + '://httpbin.org/image/png'
+    with vcr.use_cassette(str(tmpdir.join('binary.yaml'))):
+        _, response_binary = get(url, output='raw')
+
+    with vcr.use_cassette(str(tmpdir.join('binary.yaml'))) as cassette:
+        _, cassette_response_binary = get(url, output='raw')
+        assert cassette_response_binary == response_binary
+        assert cassette.play_count == 1
+
+
 def test_post(tmpdir, scheme):
     data = {'key1': 'value1', 'key2': 'value2'}
     url = scheme + '://httpbin.org/post'
@@ -101,29 +107,73 @@ def test_post(tmpdir, scheme):
 
 def test_params(tmpdir, scheme):
     url = scheme + '://httpbin.org/get'
+    headers = {'Content-Type': 'application/json'}
     params = {'a': 1, 'b': False, 'c': 'c'}
-    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
-        _, response_json = get(url, as_text=False, params=params)
 
     with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
-        _, cassette_response_json = get(url, as_text=False, params=params)
+        _, response_json = get(url, output='json', params=params, headers=headers)
+
+    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
+        _, cassette_response_json = get(url, output='json', params=params, headers=headers)
         assert cassette_response_json == response_json
         assert cassette.play_count == 1
 
 
 def test_params_same_url_distinct_params(tmpdir, scheme):
     url = scheme + '://httpbin.org/get'
+    headers = {'Content-Type': 'application/json'}
     params = {'a': 1, 'b': False, 'c': 'c'}
-    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
-        _, response_json = get(url, as_text=False, params=params)
 
     with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
-        _, cassette_response_json = get(url, as_text=False, params=params)
+        _, response_json = get(url, output='json', params=params, headers=headers)
+
+    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
+        _, cassette_response_json = get(url, output='json', params=params, headers=headers)
         assert cassette_response_json == response_json
         assert cassette.play_count == 1
 
     other_params = {'other': 'params'}
     with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
-        response, cassette_response_text = get(url, as_text=True, params=other_params)
+        response, cassette_response_text = get(url, output='text', params=other_params)
         assert 'No match for the request' in cassette_response_text
         assert response.status == 599
+
+
+def test_params_on_url(tmpdir, scheme):
+    url = scheme + '://httpbin.org/get?a=1&b=foo'
+    headers = {'Content-Type': 'application/json'}
+
+    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
+        _, response_json = get(url, output='json', headers=headers)
+        request = cassette.requests[0]
+        assert request.url == url
+
+    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
+        _, cassette_response_json = get(url, output='json', headers=headers)
+        request = cassette.requests[0]
+        assert request.url == url
+        assert cassette_response_json == response_json
+        assert cassette.play_count == 1
+
+
+def test_aiohttp_test_client(aiohttp_client, tmpdir):
+    loop = asyncio.get_event_loop()
+    app = aiohttp_app()
+    url = '/'
+    client = loop.run_until_complete(aiohttp_client(app))
+
+    with vcr.use_cassette(str(tmpdir.join('get.yaml'))):
+        response = loop.run_until_complete(client.get(url))
+
+    assert response.status == 200
+    response_text = loop.run_until_complete(response.text())
+    assert response_text == 'hello'
+
+    with vcr.use_cassette(str(tmpdir.join('get.yaml'))) as cassette:
+        response = loop.run_until_complete(client.get(url))
+
+    request = cassette.requests[0]
+    assert request.url == str(client.make_url(url))
+    response_text = loop.run_until_complete(response.text())
+    assert response_text == 'hello'
+    assert cassette.play_count == 1
